// GDP and MOBILITY

//--------------------------------------------------------------------------------------------------// CREATE SAMPLE FOR ANALYSIS
//--------------------------------------------------------------------------------------------------
use data_for_mobility_regressions, clear


global datefirst = "30sep2019"
global datelast = "30apr2021" // "21apr2021"
global datelastm30 = "31mar2021" // "20mar2021"



keep if tin($datefirst,$datelast)


merge m:1 country using temp_covidrelevant, nogenerate
drop if covidrelevant==.


tabulate country




save temp_sample_for_mobility_regressions.dta, replace


// Mobility Regressions
use temp_sample_for_mobility_regressions.dta, clear

gen quarter = qofd(date)

replace pct_diff_gdp = pct_diff_gdp*100


gen qq = "2019Q4" if quarter==239
replace qq = "2020Q1" if quarter==240
replace qq = "2020Q2" if quarter==241
replace qq = "2020Q3" if quarter==242
replace qq = "2020Q4" if quarter==243
replace qq = "2021Q1" if quarter==244
replace qq = "2021Q2" if quarter==245



collapse (first) qq pct_diff_gdp gdp leader (mean) mobgweek* stringency casespmnew_ma7 deathspmnew_ma7 , by(country quarter)



encode country, gen(country_coded) 

xtset country_coded quarter

merge m:1 country using temp_country_weights.dta, nogen

keep if country_weights~=. | leader==1













drop if quarter==245

egen count_gdp = total(!missing(gdp)), by(country)


list country count_gdp if quarter==240 & count_gdp<6

// Drop all countries with less than 6 GDP obs b/w 2019Q4 and 2021Q1
drop if count_gdp<6





sort country quarter
by country: gen gdp_2019 = gdp if quarter==239
by country: egen mean_gdp_2019 = mean(gdp_2019)
by country: gen gdp_prepand = 100*(gdp/mean_gdp_2019 - 1)

// Calculate and drop from sample all countries with rising GDP in 2020Q2
list country gdp_prepand if qq=="2020Q2" & gdp_prepand>0
gen igdp_nodecline_20Q2 = 0 
replace igdp_nodecline_20Q2 = 1 if qq=="2020Q2" & gdp_prepand>0
egen igdp_nodecline = max(igdp_nodecline_20Q2), by(country)
list country gdp_prepand igdp_nodecline if igdp_nodecline==1
drop if igdp_nodecline==1

sort country_coded quarter



///-----------------------------------
/// GDP EFFECTS
///-----------------------------------

regress gdp_prepand i.quarter mobgweek if quarter>=240 & quarter<=244, vce(robust)

regress gdp_prepand mobgweek if quarter>=240 & quarter<=244, vce(robust)

save temp_quarterly_data.dta, replace



/*


///---------------------------------------
/// VACCINATION AND MOBILITY DIFFERENTIALS
///---------------------------------------

use temp_chartdata, clear

// Calculate difference in vaccination and mobility
tabulate leader if tin(31mar2021,31mar2021), sum(vax)
tabulate leader if tin(1jan2021,30mar2021), sum(vax)

tabulate leader if tin($initialcontrol,$finalcontrol), sum(mobvar)
tabulate leader if tin($treatment,$datelast), sum(mobvar)




